@@ -8,6 +8,7 @@ from sqlglot.dialects.dialect import (
     inline_array_sql,
     rename_func,
     timestrtotime_sql,
+    ts_or_ds_to_date_sql,
     var_map_sql,
 )
 from sqlglot.expressions import Literal
@@ -149,6 +150,10 @@ class Snowflake(Dialect):
         FUNCTIONS = {
             **parser.Parser.FUNCTIONS,
             "ARRAYAGG": exp.ArrayAgg.from_arg_list,
+            "DATE_TRUNC": lambda args: exp.DateTrunc(
+                unit=exp.Literal.string(seq_get(args, 0).name),  # type: ignore
+                this=seq_get(args, 1),
+            ),
             "IFF": exp.If.from_arg_list,
             "TO_TIMESTAMP": _snowflake_to_timestamp,
             "ARRAY_CONSTRUCT": exp.Array.from_arg_list,
@@ -214,7 +219,6 @@ class Snowflake(Dialect):
         }
 
     class Generator(generator.Generator):
-        CREATE_TRANSIENT = True
         PARAMETER_TOKEN = "$"
 
         TRANSFORMS = {
@@ -236,6 +240,7 @@ class Snowflake(Dialect):
             exp.TimeStrToTime: timestrtotime_sql,
             exp.TimeToUnix: lambda self, e: f"EXTRACT(epoch_second FROM {self.sql(e, 'this')})",
             exp.Trim: lambda self, e: self.func("TRIM", e.this, e.expression),
+            exp.TsOrDsToDate: ts_or_ds_to_date_sql("snowflake"),
             exp.UnixToTime: _unix_to_time_sql,
             exp.DayOfWeek: rename_func("DAYOFWEEK"),
         }
@@ -250,6 +255,11 @@ class Snowflake(Dialect):
             "replace": "RENAME",
         }
 
+        PROPERTIES_LOCATION = {
+            **generator.Generator.PROPERTIES_LOCATION,  # type: ignore
+            exp.SetProperty: exp.Properties.Location.UNSUPPORTED,
+        }
+
         def ilikeany_sql(self, expression: exp.ILikeAny) -> str:
             return self.binary(expression, "ILIKE ANY")
 
